@@ -8,7 +8,7 @@ use routines;
 
 use parent 'Data::Object::Name';
 
-our $VERSION = '2.01'; # VERSION
+our $VERSION = '2.02'; # VERSION
 
 # METHODS
 
@@ -150,6 +150,16 @@ method cop($func, @args) {
   return sub { $next->(@args ? (@args, @_) : @_) };
 }
 
+method eval(@args) {
+  local $@;
+
+  my $result = eval join ' ', map "$_", "package @{[$self->package]};", @args;
+
+  Carp::confess $@ if $@;
+
+  return $result;
+}
+
 method functions() {
   my @functions;
 
@@ -197,6 +207,11 @@ method inherits() {
   return $self->array('ISA');
 }
 
+method inc() {
+
+  return $INC{$self->format('path', '%s.pm')};
+}
+
 my $loaded_spaces = {};
 
 method load() {
@@ -235,6 +250,16 @@ method load() {
   return $class;
 }
 
+method loaded() {
+  my $class = $self->package;
+  my $pexpr = $self->format('path', '%s.pm');
+
+  my $is_loaded_eval = $loaded_spaces->{$class};
+  my $is_loaded_used = $INC{$pexpr};
+
+  return ($is_loaded_eval || $is_loaded_used) ? 1 : 0;
+}
+
 method methods() {
   my @methods;
 
@@ -784,6 +809,29 @@ and if successful returns a closure.
 
 =cut
 
+=head2 eval
+
+  eval(Str @args) : Any
+
+The eval method takes a list of strings and evaluates them under the namespace
+represented by the instance.
+
+=over 4
+
+=item eval example #1
+
+  package main;
+
+  use Data::Object::Space;
+
+  my $space = Data::Object::Space->new('foo');
+
+  $space->eval('our $VERSION = 0.01');
+
+=back
+
+=cut
+
 =head2 functions
 
   functions() : ArrayRef
@@ -898,6 +946,28 @@ The id method returns the fully-qualified package name as a label.
 
 =cut
 
+=head2 inc
+
+  inc() : Str
+
+The inc method returns the path of the namespace if it exists in C<%INC>.
+
+=over 4
+
+=item inc example #1
+
+  package main;
+
+  my $space = Data::Object::Space->new('Data/Object/Space');
+
+  $space->inc;
+
+  # lib/Data/Object/Space.pm
+
+=back
+
+=cut
+
 =head2 inherits
 
   inherits() : ArrayRef
@@ -972,6 +1042,49 @@ C<meta>, or C<import> routine it will be recognized as having been loaded.
 
 =cut
 
+=head2 loaded
+
+  loaded() : Int
+
+The loaded method checks whether the package namespace is already loaded
+returns truthy or falsy.
+
+=over 4
+
+=item loaded example #1
+
+  package main;
+
+  use Data::Object::Space;
+
+  my $space = Data::Object::Space->new('data/dumper');
+
+  $space->loaded;
+
+  # 0
+
+=back
+
+=over 4
+
+=item loaded example #2
+
+  package main;
+
+  use Data::Object::Space;
+
+  my $space = Data::Object::Space->new('data/dumper');
+
+  $space->load;
+
+  $space->loaded;
+
+  # 1
+
+=back
+
+=cut
+
 =head2 methods
 
   methods() : ArrayRef
